.. _i18n_chapter:

Internationalization
====================

Language negotation
-------------------

Unless a ``target_language`` keyword argument is passed to the render-method of the template, an attempt to negotiate the language using ``zope.i18n.negotiate`` is made.

Consult the documentation of :mod:`zope.i18n` to learn how to implement a language negotiator.